km3modules.parser.CHParser
==========================

.. currentmodule:: km3modules.parser

.. autoclass:: CHParser

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CHParser.__init__
      ~CHParser.add
      ~CHParser.configure
      ~CHParser.expose
      ~CHParser.finish
      ~CHParser.get
      ~CHParser.pre_finish
      ~CHParser.process
      ~CHParser.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CHParser.name
      ~CHParser.parse_map
   
   